.. moduleauthor:: Paul Ross <apaulross@gmail.com>
.. sectionauthor:: Paul Ross <apaulross@gmail.com>

.. _TotalDepth.LIS.core.Rle:

TotalDepth.LIS.core.Rle (Run Length Encoding)
====================================================

.. toctree::
   :maxdepth: 2

.. automodule:: TotalDepth.LIS.core.Rle
    :member-order: bysource
    :members:
    :special-members:

